/*
 * Ind_WrapFitness.hpp
 *
 *  Created on: Mar 19, 2015
 *      Author: Joost Huizinga
 *
 * A wrapper that enables us to add a fitness value to an arbitrary individual.
 * Other fitness functions will require different wrappers.
 *
 * This class does not need to be edited.
 */

#ifndef IND_WRAPFITNESS_HPP_
#define IND_WRAPFITNESS_HPP_

template<typename Indiv>
class IndivFitness: public Indiv
{
public:

    /**
     * Creates an instance of the fitness individual based on the parent type.
     *
     * @param parent An instance of the parent type.
     */
    IndivFitness(const Indiv& parent): Indiv(parent), _fitness(0){
        //nix
    }

    /**
     * Creates an instance of the fitness individual, implicitly calling the constructor
     * of the parent type.
     */
    IndivFitness(): _fitness(0){
        //nix
    }

    /**
     * Sets the fitness of this individual.
     *
     * @param fitness The fitness of the individual as a double.
     */
    void setFitness(double fitness){
        _fitness = fitness;
    }

    /**
     * Gets this fitness of this individual.
     *
     * @return The fitness of this individual as a double.
     */
    double getFitness(){
        return _fitness;
    }

private:
    double _fitness;
};



#endif /* IND_WRAPFITNESS_HPP_ */
